@@ -49,7 +49,10 @@ impl Context {
     }
     /// Wait for the next message from the mailbox
     pub(crate) async fn mailbox_next(&mut self) -> Option<RelayMessage> {
-        self.mailbox.recv().await
+        self.mailbox.recv().await.map(|msg| {
+            trace!("{}: received new message!", self.address());
+            msg
+        })
     }
 }
 
@@ -230,7 +233,7 @@ impl Context {
     /// [`Context::stop`](Context::stop) function instead!
     pub async fn stop_now(&mut self) -> Result<()> {
         let tx = self.sender.clone();
-        info!("Shutting down all workers");
+        info!("Immediately shutting down all workers");
         let (msg, _) = NodeMessage::stop_node(ShutdownType::Immediate);
 
         match tx.send(msg).await {
